<template>
    <div
        element-loading-text="数据加载中..."
        element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)"
        v-loading.fullscreen.lock="loading"
    >
        <el-dialog
            v-dialogDrag
            :title="type + '噪音分级'"
            :visible="visible"
            :before-close="handleClose"
            :close-on-click-modal="false"
            v-if="visible"
            width="50%"
            top="6vh"
            :class="[loading ? 'dialog-box' : '']"
        >
            <div>
                <el-form
                    ref="form"
                    :rules="rules"
                    :model="formData"
                    label-width="80px"
                >
                    <el-row>
                        <el-col :span="12">
                            <el-form-item label="噪音分类" prop="noiseTypeId">
                                <el-select
                                    style="width: 100%"
                                    v-model="formData.noiseTypeId"
                                    placeholder="请选择噪音分类"
                                >
                                    <el-option
                                        v-for="item in sortList"
                                        :key="item.id"
                                        :label="item.name"
                                        :value="item.id"
                                    >
                                    </el-option>
                                </el-select>
                            </el-form-item>
                        </el-col>
                        <el-col :span="12">
                            <el-form-item label="分类级别" prop="level">
                                <el-select
                                    style="width: 100%"
                                    v-model="formData.level"
                                    placeholder="请选择分类级别"
                                >
                                    <el-option
                                        v-for="item in fljbList"
                                        :key="item.value"
                                        :label="item.name"
                                        :value="item.value"
                                    >
                                    </el-option>
                                </el-select>
                            </el-form-item>
                        </el-col>
                    </el-row>

                    <el-row>
                        <el-col :span="12">
                            <el-form-item label="噪音编码" prop="code">
                                <el-input
                                    clearable
                                    style="width: 100%"
                                    v-model="formData.code"
                                    placeholder="请输入噪音编码"
                                ></el-input>
                            </el-form-item>
                        </el-col>
                        <el-col :span="12">
                            <el-form-item
                                label="白天分贝"
                                prop="daytimeNoiseLevel"
                            >
                                <el-input-number
                                    v-model="formData.daytimeNoiseLevel"
                                    placeholder="请输入白天分贝"
                                    controls-position="right"
                                    :min="0"
                                ></el-input-number>
                                分贝
                            </el-form-item>
                        </el-col>
                    </el-row>

                    <el-row>
                        <el-col :span="12">
                            <el-form-item
                                label="夜晚分贝"
                                prop="nightNoiseLevel"
                            >
                                <el-input-number
                                    v-model="formData.nightNoiseLevel"
                                    placeholder="请输入夜晚分贝"
                                    controls-position="right"
                                    :min="0"
                                ></el-input-number>
                                分贝
                            </el-form-item>
                        </el-col>
                    </el-row>
                </el-form>
            </div>
            <div
                slot="footer"
                class="dialog-footer"
                :style="loading ? 'position: relative;z-index: -1;' : ''"
            >
                <el-button @click="handleClose">取消</el-button>
                <el-button
                    type="primary"
                    @click="handleSave"
                    :loading="btnLoading"
                    >确认</el-button
                >
            </div>
        </el-dialog>
    </div>
</template>
        
<script>
import utils from '@/utils.js'
import NoiseLevel from '@/api/basicConfiguration/NoiseLevel'
import NoiseClassify from '@/api/basicConfiguration/NoiseClassify'
import dictUtils from '@/components/dict/DictSelectUtils.js'
export default {
    props: {},
    name: 'NoiseLevelDialog',
    data() {
        return {
            visible: false,
            loading: false,
            type: '新增',
            rules: {
                noiseTypeId: [
                    {
                        required: true,
                        message: '请选择噪音分类',
                        trigger: 'change',
                    },
                ],
                level: [
                    {
                        required: true,
                        message: '请选择分类级别',
                        trigger: 'change',
                    },
                ],
                code: [
                    {
                        required: true,
                        message: '请输入分级编码',
                        trigger: 'blur',
                    },
                ],
                daytimeNoiseLevel: [
                    {
                        required: true,
                        message: '请输入白天分贝',
                        trigger: 'blur',
                    },
                ],
                nightNoiseLevel: [
                    {
                        required: true,
                        message: '请输入夜晚分贝',
                        trigger: 'blur',
                    },
                ],
            },
            formData: {},
            sortList: [], //分类
            btnLoading: false,
        }
    },
    created() {
        this.fljbList = dictUtils.getDictItemsFromCache('fljb')
        this.getSortData()
    },
    methods: {
        getSortData() {
            NoiseClassify.dataQuery(
                {
                    pageBean: {
                        page: 1,
                        pageSize: -1,
                    },
                },
                (res) => {
                    this.sortList = res.rows
                }
            )
        },

        open(data) {
            this.formData = {}
            this.visible = true
            this.type = '新增'
            if (this.fljbList.length > 0) {
                this.formData.level = this.fljbList[0].value
            }
            if (this.sortList.length > 0) {
                this.formData.noiseTypeId = this.sortList[0].id
            }
        },
        handleClose() {
            this.visible = false
        },
        //编辑
        edit(id) {
            this.formData = {}
            this.visible = true
            this.type = '编辑'
            NoiseLevel.detailId(id, (res) => {
                this.formData = res
            })
        },
        //保存
        handleSave() {
            this.$refs.form.validate((valid) => {
                if (valid) {
                    this.btnLoading = true

                    let method
                    if (this.type === '新增') {
                        method = NoiseLevel.addSave
                    } else {
                        method = NoiseLevel.upData
                    }
                    method(this.formData, (response) => {
                        if (response.state) {
                            this.$notify({
                                type: 'success',
                                message: this.type + '成功',
                                duration: 2000,
                            })
                            this.handleClose()
                            this.$emit('getData')
                        } else {
                            this.$message.warning(response.message)
                        }
                        this.btnLoading = false
                    })
                } else {
                    this.$notify({
                        type: 'warning',
                        message: '请完善表单信息！',
                        duration: 2000,
                    })
                }
            })
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/.el-dialog__wrapper {
    overflow: hidden;
}

.dialog-footer {
    display: flex;
    justify-content: flex-end;
}

//加载遮罩
/deep/.el-dialog__body {
    box-sizing: border-box;

    .el-loading-parent--relative {
        max-height: inherit;
    }
}
</style>